summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmeshedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmmeshedit.h')
-rw-r--r--kpovmodeler/pmmeshedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmmeshedit.h b/kpovmodeler/pmmeshedit.h
index dc4dc4ae..e9d71054 100644
--- a/kpovmodeler/pmmeshedit.h
+++ b/kpovmodeler/pmmeshedit.h
@@ -36,12 +36,13 @@ class PMVectorEdit;
class PMMeshEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMMeshEdit with parent and name
*/
- PMMeshEdit( TQWidget* parent, const char* name = 0 );
+ PMMeshEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -36,12 +36,13 @@ class PMVectorEdit;
public:
/**
- * Creates a PMMeshEdit with parent and name
+ * Creates a PMMeshEdit with tqparent and name
*/